@@ -1,6 +1,6 @@
 /*
     buffy.* - simple buffering for low cpu gets() functionality (ex. for sockets).
-    Copyright (C) 2000,2002-2003  Matthew Mueller <donut AT dakotacom.net>
+    Copyright (C) 2000,2002-2004  Matthew Mueller <donut AT dakotacom.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -130,7 +130,7 @@ class c_buffy {
 			}
 		}
 		//Read a line and tokenize it at the same time.  returns number of tokens found (which may be more or less than max)
-		int btoks(CharBuffer &buf, char tok, char **toks, int max){
+		int btoks(CharBuffer &buf, char tok, char **toks, int max, bool tokfinal=true){
 			int i;
 			int num = 1;
 			buf.clear();
@@ -142,10 +142,15 @@ class c_buffy {
 				if (i==tok){
 					if (num<max) {
 						buf.append(0);
-						toks[num]=(char*)buf.size();//since buf.append could invalidate pointers into buf.c_str(), store the offset instead
+						toks[num]=(char*)(uintptr_t)buf.size();//since buf.append could invalidate pointers into buf.c_str(), store the offset instead
+						num++;
+						continue;
 					}
-					num++;
-					continue;
+					else if (tokfinal) {
+						num++;
+						continue;
+					}
+					//else fall through
 				}else if (i==13){
 					continue;
 				}else if (i==10){
@@ -155,8 +160,8 @@ class c_buffy {
 					buf.append(i);
 			}
 			char *bstr = buf.c_str();
-			for (i=0;i<num;i++)
-				toks[i] = bstr + (int)toks[i];//now that we are done appending, add the c_str location to the offsets we stored earlier to get the real locations.
+			for (i=0;i<num && i<max;i++)
+				toks[i] = bstr + (uintptr_t)toks[i];//now that we are done appending, add the c_str location to the offsets we stored earlier to get the real locations.
 			return num;
 		}
 		c_buffy(){bhead=btail=0;/*buf=NULL;buffy_bufsize=0;*/}
