@@ -1,6 +1,6 @@
 /*
     log.* - debug/error logging and exception defines
-    Copyright (C) 1999-2000  Matthew Mueller <donut@azstarnet.com>
+    Copyright (C) 1999-2002  Matthew Mueller <donut AT dakotacom.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,3 +19,24 @@
 #include "log.h"
 
 int quiet=0,debug=0;
+
+void baseEx::set_params(const char *file, int line, const char * s, va_list ap) {
+    mfile = file; mline = line;
+    char *cstr;
+    vasprintf(&cstr,s,ap);
+    str=cstr;
+    free(cstr);
+}
+
+void print_ex_with_message(const baseEx &e, const char *m, ...) {
+    va_list ap;
+    va_start(ap,m);
+    vfprintf(stderr, m, ap);
+    va_end(ap);
+    PERROR_nnl(" (");
+    if (debug>=DEBUG_MIN) {
+        printCaughtEx_nnl(e);
+        PERROR(")");
+    } else
+        PERROR("%s)",e.getExStr());
+}
