@@ -1,6 +1,6 @@
 /*
     misc.* - misc functions
-    Copyright (C) 1999-2003  Matthew Mueller <donut AT dakotacom.net>
+    Copyright (C) 1999-2004  Matthew Mueller <donut AT dakotacom.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "strreps.h"
 #include "log.h"
 #include "file.h"
+#include "path.h"
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -68,6 +69,10 @@ void lowerstr(string &s){
 		*i=tolower(*i);
 }
 
+bool strstartswith(const string &s, const string &t) {
+	return s.substr(0,t.size()) == t;
+}
+
 string regex2wildmat(const string &repat, bool ignorecase){
 	if (repat.empty())
 		return "*";
@@ -385,6 +390,9 @@ time_t decode_textage(const char *cbuf) {
 }
 
 int filecompare(const char *old_fn,const char *nfn){
+	off_t old_size, new_size;
+	if (!fsize(old_fn,&old_size) && !fsize(nfn, &new_size) && old_size!=new_size)
+		return 0;
 	c_file_fd old_f(old_fn, O_RDONLY|O_BINARY);
 	c_file_fd new_f(nfn, O_RDONLY|O_BINARY);
 	char	old_buf[4096], new_buf[4096];
