@@ -1,6 +1,6 @@
 /*
     nget - command line nntp client
-    Copyright (C) 1999-2003  Matthew Mueller <donut AT dakotacom.net>
+    Copyright (C) 1999-2004  Matthew Mueller <donut AT dakotacom.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -191,7 +191,7 @@ static void addoptions(void)
 };
 static void print_help(void){
 	printf("nget v"PACKAGE_VERSION" - nntp command line fetcher\n");
-	printf("Copyright 1999-2003 Matthew Mueller <donut AT dakotacom.net>\n");
+	printf("Copyright 1999-2004 Matthew Mueller <donut AT dakotacom.net>\n");
 	printf("\n\
 This program is free software; you can redistribute it and/or modify\n\
 it under the terms of the GNU General Public License as published by\n\
@@ -1000,19 +1000,19 @@ int main(int argc, const char ** argv){
 		{
 			char *home;
 			home=getenv("NGETHOME");
-			if (home) {
+			if (home && *home) {
 				nghome=path_join(home,"");
 			} else {
 				home=getenv("HOME");
-				if (!home)
+				if (!home || !*home)
 					throw ConfigExFatal(Ex_INIT,"HOME or NGETHOME environment var not set.");
 				nghome = home;
-				if (direxists(path_join(home,".nget4","")))
-					nghome=path_join(home,".nget4","");
-				else if (direxists(path_join(home,"_nget4","")))
-					nghome=path_join(home,"_nget4","");
+				if (direxists(path_join(home,".nget5","")))
+					nghome=path_join(home,".nget5","");
+				else if (direxists(path_join(home,"_nget5","")))
+					nghome=path_join(home,"_nget5","");
 				else
-					throw ConfigExFatal(Ex_INIT,"neither %s nor %s exist", path_join(home,".nget4","").c_str(), path_join(home,"_nget4","").c_str());
+					throw ConfigExFatal(Ex_INIT,"neither %s nor %s exist", path_join(home,".nget5","").c_str(), path_join(home,"_nget5","").c_str());
 			}
 		}
 		ngcachehome = nghome;
@@ -1024,11 +1024,21 @@ int main(int argc, const char ** argv){
 		else {
 			nget_options options;
 			{
-				string ngetrcfn = nghome + ".ngetrc";
-				if (!fexists(ngetrcfn)) {
-					ngetrcfn = nghome + "_ngetrc";
+				char *cp;
+				cp = getenv("NGETRC");
+				string ngetrcfn;
+				if (cp && *cp) {
+					ngetrcfn = cp;
 					if (!fexists(ngetrcfn))
+						throw ConfigExFatal(Ex_INIT,"NGETRC %s: not found", ngetrcfn.c_str());
+				}
+				else {
+					ngetrcfn = nghome + ".ngetrc";
+					if (!fexists(ngetrcfn)) {
+						ngetrcfn = nghome + "_ngetrc";
+						if (!fexists(ngetrcfn))
 							throw ConfigExFatal(Ex_INIT,"neither %s nor %s exist", (nghome + ".ngetrc").c_str(), ngetrcfn.c_str());
+					}
 				}
 				CfgSection cfg(ngetrcfn);
 				const CfgSection *galias,*halias,*hpriority;
@@ -1071,8 +1081,8 @@ int main(int argc, const char ** argv){
 				options.set_makedirs(cfg.geta("makedirs"));
 				
 				cfg.get("cachedir",ngcachehome);//.ngetrc setting overrides default
-				char *cp=getenv("NGETCACHE");//environment var overrides .ngetrc
-				if (cp)
+				cp=getenv("NGETCACHE");//environment var overrides .ngetrc
+				if (cp && *cp)
 					ngcachehome=cp;
 				ngcachehome = path_join(ngcachehome, "");
 				if (!direxists(ngcachehome))
