@@ -1,6 +1,6 @@
 /*
     prot_nntp.* - nntp protocol handler
-    Copyright (C) 1999-2003  Matthew Mueller <donut AT dakotacom.net>
+    Copyright (C) 1999-2004  Matthew Mueller <donut AT dakotacom.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -193,10 +193,15 @@ void c_prot_nntp::nntp_dogrouplist(const char *wildmat){
 
 void c_prot_nntp::nntp_dogroupdescriptions(const char *wildmat){
 	ulong bytes=0, done=0;
+	int r;
 	if (wildmat)
-		chkreply(stdputline(quiet<2,"LIST NEWSGROUPS %s", wildmat));
+		r=stdputline(quiet<2,"LIST NEWSGROUPS %s", wildmat);
 	else
-		chkreply(stdputline(quiet<2,"LIST NEWSGROUPS"));
+		r=stdputline(quiet<2,"LIST NEWSGROUPS");
+	if (r/100!=2) {
+		// if server doesn't support LIST NEWSGROUPS, just ignore the error.
+		return;
+	}
 	DumbProgress progress;
 	while (1) {
 		if (progress.needupdate())
@@ -223,7 +228,7 @@ void c_prot_nntp::nntp_dogroupdescriptions(const char *wildmat){
 
 void c_prot_nntp::nntp_grouplist(int update, const nget_options &options){
 	if (!glist)
-		glist = new c_nntp_grouplist(nghome+"newsgroups");
+		glist = new c_nntp_grouplist(ngcachehome+"newsgroups");
 	if (update) {
 		c_server::ptr s;
 		list<c_server::ptr> doservers;
@@ -645,7 +650,7 @@ void c_prot_nntp::doxpat(c_nrange &r, c_xpat::ptr xpat, ulong total, ulong lowes
 		bytes+=getline(debug>=DEBUG_ALL);
 		if (cbuf[0]=='.')break;
 		an = strtoul(cbuf, &eptr, 10);
-		if (*cbuf=='\0' || *eptr!=' ') {
+		if (*cbuf=='\0' || !(*eptr==' ' || *eptr=='\t')) {
 			printf("error retrieving article number\n");
 			continue;
 		}
@@ -723,7 +728,7 @@ void c_prot_nntp::nntp_group(const c_group_info::ptr &ngroup, bool getheaders, c
 //	if (gcache) delete gcache;
 	cleanupcache();
 
-	midinfo=new meta_mid_info(nghome, ngroup); 
+	midinfo=new meta_mid_info(ngcachehome, ngroup); 
 	//gcache=new c_nntp_cache(nghome,group->group + ",cache");
 	gcache=new c_nntp_cache(ngcachehome, group, midinfo);
 	if (getheaders){
@@ -1047,14 +1052,14 @@ void c_prot_nntp::nntp_retrieve(const vector<c_group_info::ptr> &rgroups, const
 	if (rgroups.size()!=1) {
 		cleanupcache();
 		group = NULL;
-		midinfo=new meta_mid_info(nghome, rgroups);
+		midinfo=new meta_mid_info(ngcachehome, rgroups);
 	} else {
 		if (rgroups.front() != group) {
 			cleanupcache();
 			group = rgroups.front();
 		}
 		if (!midinfo) {
-			midinfo=new meta_mid_info(nghome, group);
+			midinfo=new meta_mid_info(ngcachehome, group);
 		}
 	}
 	gcache=new c_nntp_cache();
@@ -1075,7 +1080,7 @@ void c_prot_nntp::nntp_retrieve(const vector<c_group_info::ptr> &rgroups, const
 	if (rgroups.size()!=1) {
 		cleanupcache();
 		group = NULL;
-		midinfo=new meta_mid_info(nghome, rgroups);
+		midinfo=new meta_mid_info(ngcachehome, rgroups);
 		nntp_cache_getfiles(&filec, &parhandler, &gcache_ismultiserver, ngcachehome, rgroups, midinfo, getinfos);
 	} else {
 		assert(rgroups.front());
@@ -1090,7 +1095,7 @@ void c_prot_nntp::nntp_retrieve(const vector<c_group_info::ptr> &rgroups, const
 				group = rgroups.front();
 			}
 			if (!midinfo) {
-				midinfo=new meta_mid_info(nghome, rgroups);
+				midinfo=new meta_mid_info(ngcachehome, rgroups);
 			}
 
 			nntp_cache_getfiles(&filec, &parhandler, &gcache_ismultiserver, ngcachehome, group, midinfo, getinfos);
@@ -1208,9 +1213,9 @@ void c_prot_nntp::nntp_doretrieve(c_nntp_files_u &filec, ParHandler &parhandler,
 						usepath="";
 					else usepath=fr->temppath.c_str();
 					if (optionflags & GETFILES_TEMPSHORTNAMES)
-						asprintf(&fn,"%s%lx.%03i",usepath,f->fileid,(*curp).first);
+						asprintf(&fn,"%s%lx.%03i",usepath,f->getfileid(),(*curp).first);
 					else
-						asprintf(&fn,"%sngettemp-%lx.%03i",usepath,f->fileid,(*curp).first);
+						asprintf(&fn,"%sngettemp-%lx.%03i",usepath,f->getfileid(),(*curp).first);
 				}
 				if (!fexists(fn)){
 					ainfo.partreq = f->req;
