@@ -1,6 +1,6 @@
 /*
     strtoker.* - good strtok replacements
-    Copyright (C) 1999-2002  Matthew Mueller <donut@azstarnet.com>
+    Copyright (C) 1999-2002  Matthew Mueller <donut AT dakotacom.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ class strtoker {
 		char * operator[](int i){return toks[i];}
 		int tok(char *str);
 		strtoker(int num,char tok);
-		~strtoker(){delete toks;}
+		~strtoker(){delete [] toks;}
 };
 
 #endif
