@@ -3,7 +3,7 @@
 #    dumbnntpd.py - simple threaded nntp server daemon for testing nntp client posting.
 #    Saves all POSTed articles in sequentially numbered files in the current dir.
 #
-#    Copyright (C) 2002-2003  Matthew Mueller <donut AT dakotacom.net>
+#    Copyright (C) 2002-2004  Matthew Mueller <donut AT dakotacom.net>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -77,7 +77,7 @@ def main():
 	for o,a in opts:
 		if o=='-p':
 			port = int(a)
-	servers = nntpd.NNTPD_Master([nntpd.NNTPTCPServer(("127.0.0.1",port), NNTPRequestHandler)])
+	servers = nntpd.NNTPD_Master([nntpd.NNTPTCPServer((nntpd.serveraddr,port), NNTPRequestHandler)])
 	for a in args:
 		servers.servers[0].addarticle(["test"], nntpd.FileArticle(open(a)))
 	servers.start()
