@@ -1,5 +1,5 @@
 #    nntpd.py - simple threaded nntp server classes for testing purposes.
-#    Copyright (C) 2002-2003  Matthew Mueller <donut AT dakotacom.net>
+#    Copyright (C) 2002-2004  Matthew Mueller <donut AT dakotacom.net>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -21,6 +21,21 @@ import os, select
 import time
 import threading
 import SocketServer
+import socket
+
+#allow testing with ipv6.
+if os.environ.get('TEST_NGET_IPv6'):
+	serveraddr="::1"
+	serveraf=socket.AF_INET6
+else:
+	serveraddr="127.0.0.1"
+	serveraf=socket.AF_INET
+
+def addressstr(address):
+	host,port=address[:2]
+	if ':' in host:
+		return '[%s]:%s'%(host,port)
+	return '%s:%s'%(host,port)
 
 def chomp(line):
 	if line[-2:] == '\r\n': return line[:-2]
@@ -113,7 +128,7 @@ class NNTPRequestHandler(SocketServer.StreamRequestHandler):
 	def handle(self):
 		self.server.incrcount("_conns")
 		readline = self.rfile.readline
-		self.nwrite("200 Hello World, %s"%(':'.join(map(str,self.client_address))))
+		self.nwrite("200 Hello World, %s"%addressstr(self.client_address))
 		self.group = None
 		self._tmpuser = None
 		self.authed = self.server.auth['']
@@ -245,7 +260,7 @@ class NNTPRequestHandler(SocketServer.StreamRequestHandler):
 			article = self.group.articles[anum]
 			val = getattr(article, field, "")
 			if matcher(val):
-				self.nwrite(str(anum)+' '+val)
+				self.nwrite(str(anum)+self.server.xpat_field_sep+val)
 		self.nwrite('.')
 	def cmd_article(self, args):
 		if args[0]=='<':
@@ -290,6 +305,7 @@ class StoppableThreadingTCPServer(SocketServer.ThreadingTCPServer):
 			s1.close()
 		else:
 			self.controlr, self.controlw = os.pipe()
+		self.address_family=serveraf
 		SocketServer.ThreadingTCPServer.__init__(self, addr, handler)
 
 	def stop_serving(self):
@@ -328,6 +344,7 @@ class NNTPTCPServer(StoppableThreadingTCPServer):
 		self.adduser('','')
 		self.lock = threading.Lock()
 		self.counts = {}
+		self.xpat_field_sep = ' '
 	
 	def count(self, key):
 		return self.counts.get(key, 0)
@@ -366,7 +383,7 @@ class NNTPD_Master:
 		self.threads = []
 		if type(servers_num)==type(1): #servers_num is integer number of servers to start
 			for i in range(servers_num):
-				self.servers.append(NNTPTCPServer(("127.0.0.1", 0))) #port 0 selects a port automatically.
+				self.servers.append(NNTPTCPServer((serveraddr, 0))) #port 0 selects a port automatically.
 		else: #servers_num is a list of servers already created
 			self.servers.extend(servers_num)
 			
