@@ -1,5 +1,5 @@
 #    util.py - nget test utility stuff
-#    Copyright (C) 2002-2003  Matthew Mueller <donut AT dakotacom.net>
+#    Copyright (C) 2002-2004  Matthew Mueller <donut AT dakotacom.net>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import os, random, sys, shutil
+import os, random, sys, shutil, nntpd
 
 def exitstatus(st):
 	if not hasattr(os, 'WEXITSTATUS'): #the os.W* funcs are only on *ix
@@ -41,7 +41,6 @@ def vspawn(cmd, args, spawn=getattr(os,"spawnvp",os.spawnv)):
 	print 'running %r %r'%(cmd,args)
 	return spawnstatus(spawn(os.P_WAIT, cmd, [cmd]+args))
 
-
 class TestNGet:
 	def __init__(self, nget, servers, **kw):
 		self.exe = nget
@@ -51,7 +50,7 @@ class TestNGet:
 		os.mkdir(self.tmpdir)
 		self.writerc(servers, **kw)
 
-	def writerc(self, servers, priorities=None, options=None, hostoptions=None, extratail=""):
+	def writerc(self, servers, priorities=None, options=None, hostoptions=None, extratail="", rcfilename=None):
 		defaultoptions = {
 #			'tries': 1,
 			'tries': 2,
@@ -62,7 +61,11 @@ class TestNGet:
 #			'fullxover': 1
 		}
 
-		rc = open(os.path.join(self.rcdir, '_ngetrc'), 'w')
+		if rcfilename is None:
+			rcfilename = '_ngetrc'
+		if os.sep not in rcfilename:
+			rcfilename = os.path.join(self.rcdir, rcfilename)
+		rc = open(rcfilename, 'w')
 		if options:
 			defaultoptions.update(options)
 		for k,v in defaultoptions.items():
@@ -71,7 +74,7 @@ class TestNGet:
 		rc.write("{halias\n")
 		for i in range(0, len(servers)):
 			defaulthostoptions = {
-				'addr': ':'.join(map(str,servers[i].socket.getsockname())),
+				'addr': nntpd.addressstr(servers[i].socket.getsockname()),
 				'shortname': 'h%i'%i,
 				'id': str(i+1),
 			}
@@ -110,7 +113,7 @@ class TestNGet:
 	
 	def run_getoutput(self, args, pre="", dopath=1):
 		outputpath = os.path.join(self.rcdir,'output.'+hex(random.randrange(0,sys.maxint)))
-		status = self.run(args+' > '+outputpath, pre=pre, dopath=dopath)
+		status = self.run(args+' > '+outputpath+' 2>&1', pre=pre, dopath=dopath) #the 2>&1 will break win9x, but I'm not sure if the test suite ever actually worked there anyway.
 		f = open(outputpath, "r")
 		output = f.read()
 		f.close()
